==> seedsui-react-5.5.91.tgz: package/lib/Select/Combo/index.js <==
var _excluded = ["maskProps", "submitProps", "cancelProps", "optionProps", "ModalProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef } from 'react';
import Combo from "./../../Picker/Combo";
import Modal from "./../Modal"; // 下拉选择

import { jsx as _jsx } from "react/jsx-runtime";
export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var maskProps = _ref.maskProps,
      submitProps = _ref.submitProps,
      cancelProps = _ref.cancelProps,
      optionProps = _ref.optionProps,
      ModalProps = _ref.ModalProps,
      params = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/_jsx(Combo, _objectSpread({
    ref: ref,
    ModalComponent: Modal,
    ModalProps: _objectSpread({
      maskProps: maskProps,
      submitProps: submitProps,
      cancelProps: cancelProps,
      optionProps: optionProps
    }, ModalProps)
  }, params));
});

==> seedsui-react-5.5.92.tgz: package/lib/Select/Combo/index.js <==
var _excluded = ["maskProps", "submitProps", "cancelProps", "optionProps", "ModalProps"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef } from 'react';
import Combo from "./../../Picker/Combo";
import Modal from "./../Modal"; // 下拉选择

export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var maskProps = _ref.maskProps,
      submitProps = _ref.submitProps,
      cancelProps = _ref.cancelProps,
      optionProps = _ref.optionProps,
      ModalProps = _ref.ModalProps,
      params = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(Combo, _extends({
    ref: ref,
    ModalComponent: Modal,
    ModalProps: _objectSpread({
      maskProps: maskProps,
      submitProps: submitProps,
      cancelProps: cancelProps,
      optionProps: optionProps
    }, ModalProps)
  }, params));
});
